API Documentation
=================

.. currentmodule:: pyransame

.. autosummary::
   :toctree: _stubs

   random_surface_points
   random_surface_dataset
   random_volume_points
   random_volume_dataset
   random_line_points
   random_line_dataset
   random_vertex_points
   random_vertex_dataset
